@@ -2,4 +2,6 @@ from .bot import DGGBot
 from .chat import DGGChat
 from .event import EventType
 from .live import DGGLive, StreamInfo, YoutubeVideo, YoutubeVod
-from .message import Message, PrivateMessage, MuteMessage
+from .message import Message, PrivateMessage, MuteMessage, PinnedMessage
+
+VERSION = "0.11.1"
